==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/70/70fe73b15d802df4ec5de0315c1fe700.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png */
class __TwigTemplate_13a0864730293a7f9f24fbdf595c93a0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000>\000\000\000\000\000\000\tpHYs\000\000\000\000\000\000\000
OiCCPPhotoshop ICC profile\000\000xڝSgTS=BKKoR RB&*!\tJ!QEEȠQ,
!{kּ>H3Q5B.@
\$p\000d!s#\000~<<+\"\000x\000M0B\\t8K\000@zB\000@F&S\000\000`cb\000P-\000`'\000{\000[!\000 eD\000h;\000VE\000X0\000fK9\000-\0000IWfH\000\000\000\0000Q)\000{\000`##x\000\000FW<+*\000\000x<\$9E[-qWW.(I+6aa@.y24\000\000x6_-\"bbϫp@\000\000t~,/;m%h^uf@\000Wp~<<EJB[aW}g_Wl~<\$2]GLϒ\tbG\"IbX*QqD2\"B)%d,>5\000j>{-]cK'Xt\000\000o(hw?G%\000fIq\000\000^D\$.Tʳ?\000\000D*A,`6B\$BB
dr`)B(Ͱ*`/@4Qhp.U=pa(\tAa!ڈbX#!H\$ ɈQ\"K5H1RT UH=r9\\F;\0002G1Q=C7Fdt1r=6Ыhڏ>C03l0.B8,\tc˱\"VcϱwE\t6wB aAHXLXNH \$4\t7\tQ'\"K&b21XH,#/{C7\$C2'ITFnR#,4H#dk9, +ȅ3![
b@qS(RjJ4e2AURݨT5ZBRQ4u9̓IKhhitݕNWGw
ǈg(gwLӋT071oUX**|
J&*/TުUUT^S}FU3S\tԖUPSSg;goT?~YYLOCQ_ cx,!k
u5&|v*=9C3J3WRf?qtN\t(~))4L1e\\kXHQG6EYAJ'\\'GgSSݧ
M=:.kDwn^Loy}/TmGX\$<5qo</QC]@Caaᄑ<FFi\\\$mmƣ&&!&KMMRM);L;L֙͢5=12כ߷`ZxZ,eIZYnZ9YXUZ]F%ֻNNgðɶۮm}agbgŮ}}=
Z~sr:V:ޚΜ?}/gX3)iSGggs󈋉K.>.ȽJtq]zۯ6iܟ4)Y3sCQ?0k߬~OCOg#/c/Wװwa>>r><72Y_7ȷOo_C#dz\000%gA[z|!?:eAAA!h쐭!ΑiP~aa~'W?pX15wCsDDDޛg1O9-J5*>.j<74?.fYXXIlK9.*6nl{/]py.,:@LN8A*%w%
yg\"/6шC\\*NH*Mz쑼5y\$3,幄'L
Lݛ:v m2=:1qB!Mggfvˬen/kY-
BTZ(*geWf͉9+̳ې7ᒶKW-X潬j9<qy
+V<*mOW~&zMk^ʂkU
}]OX/Yߵa>(xoʿܔĹdff-[n
ڴ
VE/(ۻC<e;?TTTT6ݵan{4[>ɾUUMfeI?m]Nmq#׹=TR+Gw-
6
U#pDy\t
:v{vg/jBFS[b[O>zG4<YyJTiӓgό}~.`ۢ{cjotE;;\\tWW:_mt<Oǻ\\kz{f7y՞9=ݽzo~r'˻w'O_@AC݇?[jwGCˆ
8>99?rCd&ˮ/~јѡ򗓿m|x31^VwwO| (hSЧc3-\000\000\000 cHRM\000\000z%\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000o_F\000\000#IDATxI#Yzo ٙʪiOf,`xаO!3sd໎Na]|Y^\000i`}6fk鮮ʪʬ\$ŇxAF2L%|JIF\000|K3
 3\0000\000y_j0vJהaL~oC\\\\d[Ls4\0008>lx-o@l\000AHQ!6sӗ]Xb\000R砦8%@r)xg@Ȧ&6Ϭ\0001P`'V?%ТccX,8pc>0`BFߌ?AnheGb1\0006WhUD)sL\"L:uAHhMKQUzeEN͠_9e-335!\$bLX)TڬFa275HsjNMHy0|Ϟy;٧\000Lu^t>M]<6.\$
=7&6V=g+W
6YKPr 1#1JB+O^&PQk_flզ6qp
lL>0sd
Z-<['g^Ч
`91}yR)D\0008/5fk#O^۪W֛V&ئتXPVlsF9NeMdMtJ\"E=ꏖSIdcV
,w쥹孭'%ul;lp**\t.Fki8Ts*|(L09d5085C\$k~i*AP\"Wypa9U\000Mɸk\000Le\000|~ru!PGRTֺ[U@p(%Fu
sU&{\\L4YqOK!cOSe+o/OٙK￾j`놪5cd>iWKa֋S
+2e^ኟ_^˧VZ\tz/^\"э3q\t}\$jjHCiB8.^8BXYd5XI%(eyӕnO8Tq^Y4mCJOKkZPR6T]U\000&R-h݀.nkEN͟\\ x>z|?|7_cخrlNv-Np
ޏr?ݪ]QI[JzW8F_\000B\000m@ɿGE%r=C]g~u]uL\t]bq58
bZ\t)f'/Oq ,TrLZb]WKenYA7hUW@Gk7%\$
YBVB]d
uJ\000<ړMdwe}9/ހq{Zc'?SUW3l=Kqb{{?I\\JfX\000zVAs dd|pz_|})UWkP*tqC
ZR\000JH<_+[`BP@gZZ{G<{֌?\\\\
ڰWRI:浦ʢ\000t˜ǸC@ٗ[)=%?!?
1[O}G?zɵo}[٭fϳLHX[7b(v`W-Rw&؛*\000L¿x>!!j#
|@\t9qj:
4ShwW!o\000Jm
 ;L&f+pN?oYK%qSq)]e\"RZ)JR>=(Z{ƭ2ͦ:߇NהJ)X1фq_awY\000Iiص)2e\000`X`+_/q~g(\tCtGZ@(W\\BA\000n\000M\$\000LP>1>?/{|eqg_wVIS~fx=Ȳ(%<50,?[b H;6[ڤP[}Uw\000nm)]*LeRuMݑ8DYe'9m\00000ǡIы\000HI~;>p\000\$wn\000ZZBp&ʁRV
tٚ'J\000q0@
EPɍNj@\000`mT\000eݬ6\000c\000Xv{s(NQH
x1ʂ0ch6:\$I ȪB@r./*/ƞ m=u*_u[1XٯBk\\Fٵ,E<Ί8A6Uڳi\t`a\000PpŤ@&!(PC
PR\000\000!5baRZ:+?u`\$\000i&qJ4\000,>}N=`m.hX5́NnDF~4rApԊ[l:YpkvK\000@JQ
2\000\$;s<\000X|\000`V
 RBz1
`&kG7aj<vRr2#,yW
.ݤ{S7A.ߜpK~`\000R!X\000\\F.eFm0Pc)׿0)!\tSZ/'\000<A\tTdJ`ҡp~qi[\000k8
3\tr8XӪfջ#9kvϋ\000,_el\000]M
y)Jt|\000C8*0F\\N`w\000q
l\0000%9RR_\000,>U'Q୥JV\000Nj`\t֜ː+e0Fel:uQat\t#UYu+\tR`gb
\000O\$T\000@Rr{)8#D%c\000{\"^w6SxGV
0KU[
bg\000NnB^U%Npb-B+!\"8\000(\00002\000x7HO\\[*FG9jɪ!ybgA:Mx48ѤGuS)pz0XdEmSM+J*v)|
w6\000L\"NUp3J:.`d\000QR*Q-9@GDZj]Z-s\\d{,Eֻ\000\000X&۔{xu~(1m{6^u_
l\000.ʠ5j1%)<So~W):
[rm1@\000cGFh{.T+0aJX=cWe/op26`p6ӱpqk\000᾿\000a9܎݋\000`)D\\\000|ayct\0008=w9CUhRqbP&Ud(crP[/8cҬ[~|\"Oﹼ(:v[=<\tib\000W\000~;v800q'\000
RbUߪ9/\$p{3FKdPh!XZy)Z]>Jk~\$MmΤ3NMPa(_LOa03Qۿgwv
@`\t8;v2z%ڂ+Imaht+gM
\"AQE\000*6zuxמjKLV
\\:wG7D?yyZjj=<VVj\000o~mC1<q
n:pAG
`/2\tJ
 !c&\$.zu@8M&]in`GKrn0.iwQ;j*m4@]w}W:Km!}}P3^;\000mGOH>yyZla<Fg,!}ÿ>xu/A*LQ}7YCy[oESR!.
`1:04j\\s;5}¡K:PcE2nk6k&j[\$QdZQ{_Ƴ|[ݯ;]&uW*l)F'QlX`h^ͪ}+ȹBpk\000
jߊL
 X4d
@FTr}ţm&usOXxSOݣo>ۦV\\%@w;,
sJn^{z\000b/R,\000V\000s\\·\000h\000ޠ&~q/\"/K!\$\$w6v )uo6uB=/)}C8pxj}>|z;~7e1viALڲ^X.@)zr 0Y
e\000,,X@T!dD,k,{7er\$4ApJj`zy7U&ΟΟ҆Oz=i}{?s+m?^NJ<8l6o\000Ā(X\000\t\000Mbwr >:@ڢh%U=X5c6 |\" ?!n??}ַJʸky}7ݕ&8MXm&Mj(a^\000XJpm&@dSc\000rF_paamv6ʤ ?b\000lP
r=f7xQo3ApcO};uWcgd~8E;[hQj=cò-\\-Y&-\000\000s=[\000@܋p
5<omt@+eEDJdhOܪK.q\$)ip0o;EB,an8+,Qj`sueTckpT\"¦kd6V!NK\0004P
Yՠ+}|޷)SR;bǭ52Y~X0U\t2% S_/K@=85o}LQ\"ml/E+Fm+w9FqO7Ҹ'\\
\\7b.\"|Ѐ8(-#h[B@%mU\\27ޝN/!N{x\$f>-_긳T(o6v!>uQ
(8#`Y:0oǩ@&\$H
7p8!
Z!(0n1aB!rl}mxU3J`*:^4?Gϯ7Tzxvqxa~f(ފ`d4-gqGʓ]qdR*H.JԲIBq4q4`FZ(q<*ZY~dyWة! SJ3|4a?׍{8nuex?=(_yqa47,P[¥fH%\000aϹgTSTJ0!T\000/5AeR1﬏VVG#t|+0i0}[Ma.7]y]UsgGtNC8U=%n5[lZT\000\tSJ2e  *5sB-p'̻=KȾn\$D.
7ƖT;s
#oNӹ}\$xx9~6DUc'=8
\"4<Yc۽afluw(DR\0008эJXmc
ZJ-TX{y03c4@XC,2c4Ǫ&r.ŻҨ8^79>hk܏^__QCa)es<ěfJ6fUڂ۶8Hnte`8S) \\V[J+
xh:-)W
`e|e\"Eh}>:i,^X3a߭5)b&\000fLI޿ڹsW#y\000/xj{mTwͩ\00081FAm6-Ne\\Ӭ485Uztkۓ\t0-8c8gBt^fthNC;Nzh}%=t<4Ppٔ\t3юgW|\t
E^x޺?zvs`n̉`yG29B'
0H22U
܄D54i\0007\$jJ̓@3
5,&1룓^ɰ3E\$߅iwf/Ex/ޕR6ĂhI1سj5UwN\$p'NʭVKj聣6yfp}Д\000B
ht@(yftG+>iaj\\ӉiLKY8{|eLBg/6[iyw|~[E/S=`YC/ff(gC7g4~'v~7ex.0PBd,I{H@6=QII],F37XUX#L#\$VCcF \\U-
t@f?~|y
\000jayűÓ\0006قͻiJk\$bwS|ٸd濠j
n>kR3b-yYӦ
&^{!tèBXΘa 4wK9B˰EJp_׶-Eoݯ~yu#/dec`\";c9!Þ~պCsPae[s85d^A\$`9l3AM(Pqh^YVaa'UNC\000@(d\000NSlzZAg[/f}}O̾ʧ^7Q;aI|ݰM|WV9@&Tm(Qxn\\Qنw+>STD)[
MPM,\\Ί?ą~M@+f9 6K7N{K.8ƴNb>\\9RoI\$\\
^x{W@\t cNy EXjح/ۿ
f^{QXMk3xno\\bD:AM
!Q@SfYnfm6Ћ3\$ۙ+3>w&N}W慽S۸[ivi-k8Ψ䬓S|b{8
q^648ĥN\\'\000vg/fpG߆ԪRy֯Ug7F\t|u]OF%2#W6M
0T,M.98kᬱ7|w))3Jr)2,wUEaf5)eN/Zp+U^/;awX;rWȤ\$ϡ\000wbc\\5
X'+X\000\\YxFk\tВSe1?c xf1s/3 ͷ>5:%]Izh'=ϥ_
d1>~}v܅0<4Ipv˄9[QCz~Ժ~gYzkJX[]R3-1\\\"Nq}?>bLP[l
Nė0&q/4nis>!&(fg NC'ۯ?vM3t%('^36i\000'\000wJWfN3S4]^di&^9@Q +L\\x!.y`>:{Hɤ4B;կ
.gO]~\\(&嬹Il_Zh)HǍ%,\000n:~:<1au:ﰲ*/L෤\tl1\"OmTJǚ\$BMR
{z,1ý#^)~qTc};5Eop/zxU@'_E~^ƦgN]Q25:_uae郎)۳H溚T-ĄT5/@JQ
0q3+BꖕdsFgDz80&aS
g8]o88,%x8uFKڙ}97.-\000ni(e5rJk]fgi00,k}\tE\"\$2,\\;{+F1R^x0ځeG:L5
\".Κ3N#4J\"tC`\\L\$ɰ|Mw!.pxFxMJX\000BkK\tA+#q/gtASvI&WcSu2.4:I6j\"%q
J q4@X)yef%&l8>N(XV,B;]>Pel^Ëko2CWHgPo#Y*tG<5)1\000̴m8\$;SKd]*gR!\$\t*7[jZXtJO\\\tKw\\ND@N\tMTȓ'&yaJitGSI.rK}Q 8i,GK/swϜ6{yxwr{yU
\000
\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png", "/var/www/html/mauticGIT-Test/themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png");
    }
}

==> mauticGIT-Test-20260116_144917.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/70/70fe73b15d802df4ec5de0315c1fe700.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png */
class __TwigTemplate_13a0864730293a7f9f24fbdf595c93a0 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000\000\000>\000\000\000\000\000\000\tpHYs\000\000\000\000\000\000\000
OiCCPPhotoshop ICC profile\000\000xڝSgTS=BKKoR RB&*!\tJ!QEEȠQ,
!{kּ>H3Q5B.@
\$p\000d!s#\000~<<+\"\000x\000M0B\\t8K\000@zB\000@F&S\000\000`cb\000P-\000`'\000{\000[!\000 eD\000h;\000VE\000X0\000fK9\000-\0000IWfH\000\000\000\0000Q)\000{\000`##x\000\000FW<+*\000\000x<\$9E[-qWW.(I+6aa@.y24\000\000x6_-\"bbϫp@\000\000t~,/;m%h^uf@\000Wp~<<EJB[aW}g_Wl~<\$2]GLϒ\tbG\"IbX*QqD2\"B)%d,>5\000j>{-]cK'Xt\000\000o(hw?G%\000fIq\000\000^D\$.Tʳ?\000\000D*A,`6B\$BB
dr`)B(Ͱ*`/@4Qhp.U=pa(\tAa!ڈbX#!H\$ ɈQ\"K5H1RT UH=r9\\F;\0002G1Q=C7Fdt1r=6Ыhڏ>C03l0.B8,\tc˱\"VcϱwE\t6wB aAHXLXNH \$4\t7\tQ'\"K&b21XH,#/{C7\$C2'ITFnR#,4H#dk9, +ȅ3![
b@qS(RjJ4e2AURݨT5ZBRQ4u9̓IKhhitݕNWGw
ǈg(gwLӋT071oUX**|
J&*/TުUUT^S}FU3S\tԖUPSSg;goT?~YYLOCQ_ cx,!k
u5&|v*=9C3J3WRf?qtN\t(~))4L1e\\kXHQG6EYAJ'\\'GgSSݧ
M=:.kDwn^Loy}/TmGX\$<5qo</QC]@Caaᄑ<FFi\\\$mmƣ&&!&KMMRM);L;L֙͢5=12כ߷`ZxZ,eIZYnZ9YXUZ]F%ֻNNgðɶۮm}agbgŮ}}=
Z~sr:V:ޚΜ?}/gX3)iSGggs󈋉K.>.ȽJtq]zۯ6iܟ4)Y3sCQ?0k߬~OCOg#/c/Wװwa>>r><72Y_7ȷOo_C#dz\000%gA[z|!?:eAAA!h쐭!ΑiP~aa~'W?pX15wCsDDDޛg1O9-J5*>.j<74?.fYXXIlK9.*6nl{/]py.,:@LN8A*%w%
yg\"/6шC\\*NH*Mz쑼5y\$3,幄'L
Lݛ:v m2=:1qB!Mggfvˬen/kY-
BTZ(*geWf͉9+̳ې7ᒶKW-X潬j9<qy
+V<*mOW~&zMk^ʂkU
}]OX/Yߵa>(xoʿܔĹdff-[n
ڴ
VE/(ۻC<e;?TTTT6ݵan{4[>ɾUUMfeI?m]Nmq#׹=TR+Gw-
6
U#pDy\t
:v{vg/jBFS[b[O>zG4<YyJTiӓgό}~.`ۢ{cjotE;;\\tWW:_mt<Oǻ\\kz{f7y՞9=ݽzo~r'˻w'O_@AC݇?[jwGCˆ
8>99?rCd&ˮ/~јѡ򗓿m|x31^VwwO| (hSЧc3-\000\000\000 cHRM\000\000z%\000\000\000\000\000\000\000\000u0\000\000`\000\000:\000\000o_F\000\000#IDATxI#Yzo ٙʪiOf,`xаO!3sd໎Na]|Y^\000i`}6fk鮮ʪʬ\$ŇxAF2L%|JIF\000|K3
 3\0000\000y_j0vJהaL~oC\\\\d[Ls4\0008>lx-o@l\000AHQ!6sӗ]Xb\000R砦8%@r)xg@Ȧ&6Ϭ\0001P`'V?%ТccX,8pc>0`BFߌ?AnheGb1\0006WhUD)sL\"L:uAHhMKQUzeEN͠_9e-335!\$bLX)TڬFa275HsjNMHy0|Ϟy;٧\000Lu^t>M]<6.\$
=7&6V=g+W
6YKPr 1#1JB+O^&PQk_flզ6qp
lL>0sd
Z-<['g^Ч
`91}yR)D\0008/5fk#O^۪W֛V&ئتXPVlsF9NeMdMtJ\"E=ꏖSIdcV
,w쥹孭'%ul;lp**\t.Fki8Ts*|(L09d5085C\$k~i*AP\"Wypa9U\000Mɸk\000Le\000|~ru!PGRTֺ[U@p(%Fu
sU&{\\L4YqOK!cOSe+o/OٙK￾j`놪5cd>iWKa֋S
+2e^ኟ_^˧VZ\tz/^\"э3q\t}\$jjHCiB8.^8BXYd5XI%(eyӕnO8Tq^Y4mCJOKkZPR6T]U\000&R-h݀.nkEN͟\\ x>z|?|7_cخrlNv-Np
ޏr?ݪ]QI[JzW8F_\000B\000m@ɿGE%r=C]g~u]uL\t]bq58
bZ\t)f'/Oq ,TrLZb]WKenYA7hUW@Gk7%\$
YBVB]d
uJ\000<ړMdwe}9/ހq{Zc'?SUW3l=Kqb{{?I\\JfX\000zVAs dd|pz_|})UWkP*tqC
ZR\000JH<_+[`BP@gZZ{G<{֌?\\\\
ڰWRI:浦ʢ\000t˜ǸC@ٗ[)=%?!?
1[O}G?zɵo}[٭fϳLHX[7b(v`W-Rw&؛*\000L¿x>!!j#
|@\t9qj:
4ShwW!o\000Jm
 ;L&f+pN?oYK%qSq)]e\"RZ)JR>=(Z{ƭ2ͦ:߇NהJ)X1фq_awY\000Iiص)2e\000`X`+_/q~g(\tCtGZ@(W\\BA\000n\000M\$\000LP>1>?/{|eqg_wVIS~fx=Ȳ(%<50,?[b H;6[ڤP[}Uw\000nm)]*LeRuMݑ8DYe'9m\00000ǡIы\000HI~;>p\000\$wn\000ZZBp&ʁRV
tٚ'J\000q0@
EPɍNj@\000`mT\000eݬ6\000c\000Xv{s(NQH
x1ʂ0ch6:\$I ȪB@r./*/ƞ m=u*_u[1XٯBk\\Fٵ,E<Ί8A6Uڳi\t`a\000PpŤ@&!(PC
PR\000\000!5baRZ:+?u`\$\000i&qJ4\000,>}N=`m.hX5́NnDF~4rApԊ[l:YpkvK\000@JQ
2\000\$;s<\000X|\000`V
 RBz1
`&kG7aj<vRr2#,yW
.ݤ{S7A.ߜpK~`\000R!X\000\\F.eFm0Pc)׿0)!\tSZ/'\000<A\tTdJ`ҡp~qi[\000k8
3\tr8XӪfջ#9kvϋ\000,_el\000]M
y)Jt|\000C8*0F\\N`w\000q
l\0000%9RR_\000,>U'Q୥JV\000Nj`\t֜ː+e0Fel:uQat\t#UYu+\tR`gb
\000O\$T\000@Rr{)8#D%c\000{\"^w6SxGV
0KU[
bg\000NnB^U%Npb-B+!\"8\000(\00002\000x7HO\\[*FG9jɪ!ybgA:Mx48ѤGuS)pz0XdEmSM+J*v)|
w6\000L\"NUp3J:.`d\000QR*Q-9@GDZj]Z-s\\d{,Eֻ\000\000X&۔{xu~(1m{6^u_
l\000.ʠ5j1%)<So~W):
[rm1@\000cGFh{.T+0aJX=cWe/op26`p6ӱpqk\000᾿\000a9܎݋\000`)D\\\000|ayct\0008=w9CUhRqbP&Ud(crP[/8cҬ[~|\"Oﹼ(:v[=<\tib\000W\000~;v800q'\000
RbUߪ9/\$p{3FKdPh!XZy)Z]>Jk~\$MmΤ3NMPa(_LOa03Qۿgwv
@`\t8;v2z%ڂ+Imaht+gM
\"AQE\000*6zuxמjKLV
\\:wG7D?yyZjj=<VVj\000o~mC1<q
n:pAG
`/2\tJ
 !c&\$.zu@8M&]in`GKrn0.iwQ;j*m4@]w}W:Km!}}P3^;\000mGOH>yyZla<Fg,!}ÿ>xu/A*LQ}7YCy[oESR!.
`1:04j\\s;5}¡K:PcE2nk6k&j[\$QdZQ{_Ƴ|[ݯ;]&uW*l)F'QlX`h^ͪ}+ȹBpk\000
jߊL
 X4d
@FTr}ţm&usOXxSOݣo>ۦV\\%@w;,
sJn^{z\000b/R,\000V\000s\\·\000h\000ޠ&~q/\"/K!\$\$w6v )uo6uB=/)}C8pxj}>|z;~7e1viALڲ^X.@)zr 0Y
e\000,,X@T!dD,k,{7er\$4ApJj`zy7U&ΟΟ҆Oz=i}{?s+m?^NJ<8l6o\000Ā(X\000\t\000Mbwr >:@ڢh%U=X5c6 |\" ?!n??}ַJʸky}7ݕ&8MXm&Mj(a^\000XJpm&@dSc\000rF_paamv6ʤ ?b\000lP
r=f7xQo3ApcO};uWcgd~8E;[hQj=cò-\\-Y&-\000\000s=[\000@܋p
5<omt@+eEDJdhOܪK.q\$)ip0o;EB,an8+,Qj`sueTckpT\"¦kd6V!NK\0004P
Yՠ+}|޷)SR;bǭ52Y~X0U\t2% S_/K@=85o}LQ\"ml/E+Fm+w9FqO7Ҹ'\\
\\7b.\"|Ѐ8(-#h[B@%mU\\27ޝN/!N{x\$f>-_긳T(o6v!>uQ
(8#`Y:0oǩ@&\$H
7p8!
Z!(0n1aB!rl}mxU3J`*:^4?Gϯ7Tzxvqxa~f(ފ`d4-gqGʓ]qdR*H.JԲIBq4q4`FZ(q<*ZY~dyWة! SJ3|4a?׍{8nuex?=(_yqa47,P[¥fH%\000aϹgTSTJ0!T\000/5AeR1﬏VVG#t|+0i0}[Ma.7]y]UsgGtNC8U=%n5[lZT\000\tSJ2e  *5sB-p'̻=KȾn\$D.
7ƖT;s
#oNӹ}\$xx9~6DUc'=8
\"4<Yc۽afluw(DR\0008эJXmc
ZJ-TX{y03c4@XC,2c4Ǫ&r.ŻҨ8^79>hk܏^__QCa)es<ěfJ6fUڂ۶8Hnte`8S) \\V[J+
xh:-)W
`e|e\"Eh}>:i,^X3a߭5)b&\000fLI޿ڹsW#y\000/xj{mTwͩ\00081FAm6-Ne\\Ӭ485Uztkۓ\t0-8c8gBt^fthNC;Nzh}%=t<4Ppٔ\t3юgW|\t
E^x޺?zvs`n̉`yG29B'
0H22U
܄D54i\0007\$jJ̓@3
5,&1룓^ɰ3E\$߅iwf/Ex/ޕR6ĂhI1سj5UwN\$p'NʭVKj聣6yfp}Д\000B
ht@(yftG+>iaj\\ӉiLKY8{|eLBg/6[iyw|~[E/S=`YC/ff(gC7g4~'v~7ex.0PBd,I{H@6=QII],F37XUX#L#\$VCcF \\U-
t@f?~|y
\000jayűÓ\0006قͻiJk\$bwS|ٸd濠j
n>kR3b-yYӦ
&^{!tèBXΘa 4wK9B˰EJp_׶-Eoݯ~yu#/dec`\";c9!Þ~պCsPae[s85d^A\$`9l3AM(Pqh^YVaa'UNC\000@(d\000NSlzZAg[/f}}O̾ʧ^7Q;aI|ݰM|WV9@&Tm(Qxn\\Qنw+>STD)[
MPM,\\Ί?ą~M@+f9 6K7N{K.8ƴNb>\\9RoI\$\\
^x{W@\t cNy EXjح/ۿ
f^{QXMk3xno\\bD:AM
!Q@SfYnfm6Ћ3\$ۙ+3>w&N}W慽S۸[ivi-k8Ψ䬓S|b{8
q^648ĥN\\'\000vg/fpG߆ԪRy֯Ug7F\t|u]OF%2#W6M
0T,M.98kᬱ7|w))3Jr)2,wUEaf5)eN/Zp+U^/;awX;rWȤ\$ϡ\000wbc\\5
X'+X\000\\YxFk\tВSe1?c xf1s/3 ͷ>5:%]Izh'=ϥ_
d1>~}v܅0<4Ipv˄9[QCz~Ժ~gYzkJX[]R3-1\\\"Nq}?>bLP[l
Nė0&q/4nis>!&(fg NC'ۯ?vM3t%('^36i\000'\000wJWfN3S4]^di&^9@Q +L\\x!.y`>:{Hɤ4B;կ
.gO]~\\(&嬹Il_Zh)HǍ%,\000n:~:<1au:ﰲ*/L෤\tl1\"OmTJǚ\$BMR
{z,1ý#^)~qTc};5Eop/zxU@'_E~^ƦgN]Q25:_uae郎)۳H溚T-ĄT5/@JQ
0q3+BꖕdsFgDz80&aS
g8]o88,%x8uFKڙ}97.-\000ni(e5rJk]fgi00,k}\tE\"\$2,\\;{+F1R^x0ځeG:L5
\".Κ3N#4J\"tC`\\L\$ɰ|Mw!.pxFxMJX\000BkK\tA+#q/gtASvI&WcSu2.4:I6j\"%q
J q4@X)yef%&l8>N(XV,B;]>Pel^Ëko2CWHgPo#Y*tG<5)1\000̴m8\$;SKd]*gR!\$\t*7[jZXtJO\\\tKw\\ND@N\tMTȓ'&yaJitGSI.rK}Q 8i,GK/swϜ6{yxwr{yU
\000
\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png", "/var/www/mautic-ktn/themes/fpoe_kaernten_theme_full_final_v2/assets/banner-footer.png");
    }
}
